{
  lib,
  pkgs,
  inputs,
  ...
}: {
  home = {
    packages = with pkgs;
      [
        eternal-terminal
        firefox
        grc
        iamb
        jamesdsp
        jetbrains-toolbox
        kdePackages.neochat
        killall
        lm_sensors
        mpv
        playerctl
        prismlauncher
        quickemu
        quickgui
        telegram-desktop
        xdotool
        youki
        (xwinwrap.overrideAttrs {
          src = fetchFromGitHub {
            owner = "camonater62";
            repo = "xwinwrap";
            rev = "ec74e730072225ffa740bf5076a1dd0a343bb113";
            sha256 = "0vfwbcx5y1aphiaix2zps1bl7lhbhdvm6vhys2m0kwvl6igy0cc8";
          };

          buildPhase = ''
            make all
          '';

          installPhase = ''
            mkdir -p $out/bin
            mv xwinwrap $out/bin
          '';
        })
        (vesktop.overrideAttrs {withSystemVencord = false;})
      ]
      ++ (with inputs; [
        nixvim.packages.${pkgs.system}.default
      ])
      ++ (with inputs.chaotic.packages.${pkgs.system}; [
        distrobox_git
      ]);

    pointerCursor = {
      gtk.enable = true;
      x11.enable = true;
      name = "Catppuccin-Mocha-Green-Cursors";
      package = pkgs.catppuccin-cursors.mochaGreen;
      size = 24;
    };

    stateVersion = "24.05";
  };

  dconf.settings = {
    "org/virt-manager/virt-manager/connections" = {
      autoconnect = ["qemu:///system"];
      uris = ["qemu:///system"];
    };
  };

  xdg.enable = true;

  catppuccin = {
    enable = true;
    flavour = "mocha";
    accent = "green";
  };

  gtk = {
    enable = true;

    catppuccin = {
      enable = true;
      icon.enable = true;
      cursor.enable = true;
      size = "standard";
      tweaks = ["normal"];
    };
  };

  programs = {
    nix-index-database.comma.enable = true;
    nix-index.enable = true;
    ripgrep.enable = true;
    xmobar.enable = true;

    eza = {
      enable = true;
      git = true;
      icons = true;
    };

    btop = {
      enable = true;
      catppuccin.enable = true;
    };

    direnv = {
      enable = true;
      nix-direnv.enable = true;
    };

    rofi = {
      enable = true;
      catppuccin.enable = true;

      extraConfig = {
        modi = "run,drun,window";
        icon-theme = "Oranchelo";
        show-icons = true;
        terminal = "wezterm";
        drun-display-format = "{icon} {name}";
        location = 0;
        disable-history = false;
        hide-scrollbar = true;
        display-drun = "   Apps ";
        display-run = "   Run ";
        display-window = " 󰍲  Window";
        display-Network = " 󰤨  Network";
        sidebar-mode = true;
      };

      theme = {
        "*".font = "Maple Mono NF 14";
      };
    };
  };

  services = {
    picom = {
      enable = true;
      backend = "glx";
      fadeDelta = 5;
      fade = true;
      shadow = true;
      vSync = true;

      shadowExclude = [
        "class_g = 'firefox' && argb"
        "class_g *?= 'slop'"
      ];

      settings = {
        corner-radius = 10;

        blur-background-exclude = [
          "class_g = 'slop'"
        ];

        rounded-corners-exclude = [
          "window_type = 'dock'"
          "window_type = 'desktop'"
        ];

        blur = {
          method = "gaussian";
          size = 10;
          deviation = 5.0;
        };
      };
    };

    dunst = {
      enable = true;
      settings.global = {
        corner_radius = 10;
        offset = "18x53";
        frame_width = 2;
        font = "SN Pro 12";
        frame_color = lib.mkForce "#a6e3a1";
      };
      catppuccin.enable = true;
    };
  };

  nix.package = lib.mkForce pkgs.nixSuper;
}
